pub type IED_R = BitReader<IED_A>;
Field IED reader - Input Data Endian
IED
pub struct IED_R { /* private fields */ }
Get enumerated values variant
Checks if the value of the field is _0
_0
Checks if the value of the field is _1
_1