OEN_R

Type Alias OEN_R 

pub type OEN_R = BitReader<OEN_A>;
Field OEN reader - Output Data FIFO Full Interrupt Enable

Aliased Type

pub struct OEN_R { /* private fields */ }

Implementations

Source

impl OEN_R

pub fn variant(&self) -> OEN_A

Get enumerated values variant

pub fn is_0(&self) -> bool

Checks if the value of the field is _0

pub fn is_1(&self) -> bool

Checks if the value of the field is _1