CEF_R

Type Alias CEF_R 

pub type CEF_R = BitReader<CEF_A>;
Field CEF reader - Conversion End Flag

The field is modified in some way after a read operation.

Aliased Type

pub struct CEF_R { /* private fields */ }

Implementations

Source

impl CEF_R

pub fn variant(&self) -> CEF_A

Get enumerated values variant

pub fn is_0(&self) -> bool

Checks if the value of the field is _0

pub fn is_1(&self) -> bool

Checks if the value of the field is _1