OINT_W

Type Alias OINT_W 

pub type OINT_W<'a, const O: u8> = BitWriter0C<'a, u16, SRCSTAT_SPEC, OINT_A, O>;
Field OINT writer - Output Data FIFO Full Interrupt Request Flag

Aliased Type

pub struct OINT_W<'a, const O: u8> { /* private fields */ }

Implementations

Source

impl<'a, const O: u8> OINT_W<'a, O>

pub fn _0(self) -> &'a mut W

Number of data units in the output FIFO has not become equal to or greater than the specified triggering number.

pub fn _1(self) -> &'a mut W

Number of data units in the output FIFO has become equal to or greater than the specified triggering number.