pub type OEN_R = BitReader<OEN_A>;
Field OEN reader - Output Data FIFO Full Interrupt Enable
OEN
pub struct OEN_R { /* private fields */ }
Get enumerated values variant
Checks if the value of the field is _0
_0
Checks if the value of the field is _1
_1