pub type CEF_R = BitReader<CEF_A>;
Field CEF reader - Conversion End Flag
CEF
The field is modified in some way after a read operation.
pub struct CEF_R { /* private fields */ }
Get enumerated values variant
Checks if the value of the field is _0
_0
Checks if the value of the field is _1
_1