pub type OINT_W<'a, const O: u8> = BitWriter0C<'a, u16, SRCSTAT_SPEC, OINT_A, O>;
Field OINT writer - Output Data FIFO Full Interrupt Request Flag
OINT
pub struct OINT_W<'a, const O: u8> { /* private fields */ }
Number of data units in the output FIFO has not become equal to or greater than the specified triggering number.
Number of data units in the output FIFO has become equal to or greater than the specified triggering number.